summaryrefslogtreecommitdiffstats
path: root/arts/kde
diff options
context:
space:
mode:
authorDarrell Anderson <humanreadable@yahoo.com>2013-03-02 15:57:34 -0600
committerDarrell Anderson <humanreadable@yahoo.com>2013-03-02 15:57:34 -0600
commit7c0b0c9dc9fcbe9c198925bdc7ee18ac6be49f4f (patch)
treec76702a7f6310fbe9d437e347535422e836e94e9 /arts/kde
parenta2a38be7600e2a2c2b49c66902d912ca036a2c0f (diff)
parent27bbee9a5f9dcda53d8eb23863ee670ad1360e41 (diff)
downloadtdelibs-7c0b0c9dc9fcbe9c198925bdc7ee18ac6be49f4f.tar.gz
tdelibs-7c0b0c9dc9fcbe9c198925bdc7ee18ac6be49f4f.zip
Merge branch 'master' of http://scm.trinitydesktop.org/scm/git/tdelibs
Diffstat (limited to 'arts/kde')
-rw-r--r--arts/kde/CMakeLists.txt6
-rw-r--r--arts/kde/artskde.idl2
-rw-r--r--arts/kde/kartsserver.cpp12
-rw-r--r--arts/kde/kaudioconverter.cc8
-rw-r--r--arts/kde/kaudioplaystream.cpp2
-rw-r--r--arts/kde/kaudiorecordstream.cpp2
-rw-r--r--arts/kde/kconverttest.cc22
-rw-r--r--arts/kde/kioinputstream_impl.cpp76
-rw-r--r--arts/kde/kioinputstream_impl.h20
-rw-r--r--arts/kde/kiotest.cc24
-rw-r--r--arts/kde/kiotestslow.cc24
-rw-r--r--arts/kde/kplayobject.h2
-rw-r--r--arts/kde/kplayobjectcreator.cc6
-rw-r--r--arts/kde/kplayobjectcreator.h2
-rw-r--r--arts/kde/kplayobjectfactory.cc16
-rw-r--r--arts/kde/kvideowidget.cpp48
-rw-r--r--arts/kde/mcop-dcop/kmcop.cpp12
17 files changed, 142 insertions, 142 deletions
diff --git a/arts/kde/CMakeLists.txt b/arts/kde/CMakeLists.txt
index 3877ddb9d..3b585256d 100644
--- a/arts/kde/CMakeLists.txt
+++ b/arts/kde/CMakeLists.txt
@@ -18,8 +18,8 @@ include_directories(
${CMAKE_BINARY_DIR}/tdecore
${CMAKE_SOURCE_DIR}/tdecore
${CMAKE_SOURCE_DIR}/tdeui
- ${CMAKE_SOURCE_DIR}/kio
- ${CMAKE_SOURCE_DIR}/kio/kio
+ ${CMAKE_SOURCE_DIR}/tdeio
+ ${CMAKE_SOURCE_DIR}/tdeio/tdeio
)
link_directories(
@@ -65,6 +65,6 @@ add_custom_command(
tde_add_library( ${target} SHARED AUTOMOC
SOURCES ${${target}_SRCS}
VERSION 1.2.0
- LINK kio-shared mcop artsflow_idl kmedia2_idl soundserver_idl artsflow qtmcop
+ LINK tdeio-shared mcop artsflow_idl kmedia2_idl soundserver_idl artsflow qtmcop
DESTINATION ${LIB_INSTALL_DIR}
)
diff --git a/arts/kde/artskde.idl b/arts/kde/artskde.idl
index f31b49ed4..f1de50924 100644
--- a/arts/kde/artskde.idl
+++ b/arts/kde/artskde.idl
@@ -12,7 +12,7 @@ interface KFloatWatchProxy {
/*
* used for deliviering MCOP data to the playobjects
*/
-interface KIOInputStream : InputStream {
+interface TDEIOInputStream : InputStream {
boolean openURL(string url);
attribute long bufferPackets;
diff --git a/arts/kde/kartsserver.cpp b/arts/kde/kartsserver.cpp
index e030cb411..add7a7595 100644
--- a/arts/kde/kartsserver.cpp
+++ b/arts/kde/kartsserver.cpp
@@ -59,8 +59,8 @@ Arts::SoundServerV2 KArtsServer::server(void)
// aRts seems not to be running, let's try to run it
// First, let's read the configuration as in kcmarts
- KConfig config("kcmartsrc", false /*bReadOnly*/, false /*bUseKDEGlobals*/);
- KProcess proc;
+ TDEConfig config("kcmartsrc", false /*bReadOnly*/, false /*bUseKDEGlobals*/);
+ TDEProcess proc;
config.setGroup("Arts");
@@ -77,16 +77,16 @@ Arts::SoundServerV2 KArtsServer::server(void)
X11CommConfig.sync();
- proc << TQFile::encodeName(KStandardDirs::findExe(TQString::fromLatin1("tdeinit_wrapper"))).data();
+ proc << TQFile::encodeName(TDEStandardDirs::findExe(TQString::fromLatin1("tdeinit_wrapper"))).data();
if(rt)
- proc << TQFile::encodeName(KStandardDirs::findExe(TQString::fromLatin1("artswrapper"))).data();
+ proc << TQFile::encodeName(TDEStandardDirs::findExe(TQString::fromLatin1("artswrapper"))).data();
else
- proc << TQFile::encodeName(KStandardDirs::findExe(TQString::fromLatin1("artsd"))).data();
+ proc << TQFile::encodeName(TDEStandardDirs::findExe(TQString::fromLatin1("artsd"))).data();
proc << TQStringList::split( " ", config.readEntry( "Arguments", "-F 10 -S 4096 -s 60 -m artsmessage -l 3 -f" ) );
- if(proc.start(KProcess::Block) && proc.normalExit())
+ if(proc.start(TDEProcess::Block) && proc.normalExit())
{
// We could have a race-condition here.
// The correct way to do it is to make artsd fork-and-exit
diff --git a/arts/kde/kaudioconverter.cc b/arts/kde/kaudioconverter.cc
index adda3033a..1eb8c20e5 100644
--- a/arts/kde/kaudioconverter.cc
+++ b/arts/kde/kaudioconverter.cc
@@ -37,7 +37,7 @@
#include <kurl.h>
#include <kdebug.h>
#include <kmimetype.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
using namespace std;
@@ -81,12 +81,12 @@ void KAudioConverter::requestPlayObject(const KURL &url)
{
string queryInterface = "Arts::PlayObject";
- Arts::KIOInputStream inputStream;
+ Arts::TDEIOInputStream inputStream;
if(!url.isLocalFile())
{
- Arts::KIOInputStream_impl *inputStreamImpl = new Arts::KIOInputStream_impl();
- inputStream = Arts::KIOInputStream::_from_base(inputStreamImpl);
+ Arts::TDEIOInputStream_impl *inputStreamImpl = new Arts::TDEIOInputStream_impl();
+ inputStream = Arts::TDEIOInputStream::_from_base(inputStreamImpl);
TQObject::connect(inputStreamImpl, TQT_SIGNAL(mimeTypeFound(const TQString &)), TQT_SLOT(slotMimeType(const TQString &)));
diff --git a/arts/kde/kaudioplaystream.cpp b/arts/kde/kaudioplaystream.cpp
index 52743a67e..0ef5b8332 100644
--- a/arts/kde/kaudioplaystream.cpp
+++ b/arts/kde/kaudioplaystream.cpp
@@ -26,7 +26,7 @@
#include <artsflow.h>
#include <soundserver.h>
-#include <kglobal.h>
+#include <tdeglobal.h>
#include <kdebug.h>
#include <tqstring.h>
diff --git a/arts/kde/kaudiorecordstream.cpp b/arts/kde/kaudiorecordstream.cpp
index 0d180d1f1..0c11bcf04 100644
--- a/arts/kde/kaudiorecordstream.cpp
+++ b/arts/kde/kaudiorecordstream.cpp
@@ -29,7 +29,7 @@
#include <artsflow.h>
#include <soundserver.h>
-#include <kglobal.h>
+#include <tdeglobal.h>
#include <kdebug.h>
#include <tqstring.h>
diff --git a/arts/kde/kconverttest.cc b/arts/kde/kconverttest.cc
index 5382e2095..647c2f320 100644
--- a/arts/kde/kconverttest.cc
+++ b/arts/kde/kconverttest.cc
@@ -3,10 +3,10 @@
#include <tqfile.h>
#include <tqobject.h>
-#include <klocale.h>
-#include <kaboutdata.h>
-#include <kcmdlineargs.h>
-#include <kapplication.h>
+#include <tdelocale.h>
+#include <tdeaboutdata.h>
+#include <tdecmdlineargs.h>
+#include <tdeapplication.h>
#include <flowsystem.h>
#include <kplayobject.h>
@@ -18,10 +18,10 @@
using namespace std;
using namespace Arts;
-static KCmdLineOptions options[] =
+static TDECmdLineOptions options[] =
{
{ "+[URL]", I18N_NOOP("URL to open"), 0 },
- KCmdLineLastOption
+ TDECmdLineLastOption
};
KConvertTest::KConvertTest()
@@ -55,13 +55,13 @@ void KConvertTest::slotRawStreamFinished()
int main(int argc, char **argv)
{
- KAboutData aboutData("kconverttest", I18N_NOOP("KConvertTest"), I18N_NOOP("0.1"), "", KAboutData::License_GPL, "");
+ TDEAboutData aboutData("kconverttest", I18N_NOOP("KConvertTest"), I18N_NOOP("0.1"), "", TDEAboutData::License_GPL, "");
- KCmdLineArgs::init(argc, argv, &aboutData);
- KCmdLineArgs::addCmdLineOptions(options);
- KApplication app;
+ TDECmdLineArgs::init(argc, argv, &aboutData);
+ TDECmdLineArgs::addCmdLineOptions(options);
+ TDEApplication app;
- KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
+ TDECmdLineArgs *args = TDECmdLineArgs::parsedArgs();
KURL url;
diff --git a/arts/kde/kioinputstream_impl.cpp b/arts/kde/kioinputstream_impl.cpp
index 8c131bfd1..d893675cd 100644
--- a/arts/kde/kioinputstream_impl.cpp
+++ b/arts/kde/kioinputstream_impl.cpp
@@ -29,11 +29,11 @@
* until the buffer is small enough again.
*/
-#include <kapplication.h>
+#include <tdeapplication.h>
#include <kdebug.h>
-#include <kio/job.h>
-#include <kio/kmimetype.h>
-#include <kio/jobclasses.h>
+#include <tdeio/job.h>
+#include <tdeio/kmimetype.h>
+#include <tdeio/jobclasses.h>
#include <tqtimer.h>
#include <tqdatastream.h>
#include "artsversion.h"
@@ -41,9 +41,9 @@
using namespace Arts;
-const unsigned int KIOInputStream_impl::PACKET_COUNT = 10;
+const unsigned int TDEIOInputStream_impl::PACKET_COUNT = 10;
-KIOInputStream_impl::KIOInputStream_impl() : m_packetSize(2048)
+TDEIOInputStream_impl::TDEIOInputStream_impl() : m_packetSize(2048)
{
m_job = 0;
m_finished = false;
@@ -55,13 +55,13 @@ KIOInputStream_impl::KIOInputStream_impl() : m_packetSize(2048)
m_size = 0;
}
-KIOInputStream_impl::~KIOInputStream_impl()
+TDEIOInputStream_impl::~TDEIOInputStream_impl()
{
if(m_job != 0)
m_job->kill();
}
-void KIOInputStream_impl::streamStart()
+void TDEIOInputStream_impl::streamStart()
{
// prevent kill/reconnect
if (m_streamStarted) {
@@ -75,37 +75,37 @@ void KIOInputStream_impl::streamStart()
if(m_job != 0)
m_job->kill();
- m_job = KIO::get(m_url, false, false);
+ m_job = TDEIO::get(m_url, false, false);
m_job->addMetaData("accept", "audio/x-mp3, video/mpeg, application/ogg");
m_job->addMetaData("UserAgent", TQString::fromLatin1("aRts/") + TQString::fromLatin1(ARTS_VERSION));
- TQObject::connect(m_job, TQT_SIGNAL(data(KIO::Job *, const TQByteArray &)),
- this, TQT_SLOT(slotData(KIO::Job *, const TQByteArray &)));
- TQObject::connect(m_job, TQT_SIGNAL(result(KIO::Job *)),
- this, TQT_SLOT(slotResult(KIO::Job *)));
- TQObject::connect(m_job, TQT_SIGNAL(mimetype(KIO::Job *, const TQString &)),
- this, TQT_SLOT(slotScanMimeType(KIO::Job *, const TQString &)));
- TQObject::connect(m_job, TQT_SIGNAL(totalSize( KIO::Job *, KIO::filesize_t)),
- this, TQT_SLOT(slotTotalSize(KIO::Job *, KIO::filesize_t)));
+ TQObject::connect(m_job, TQT_SIGNAL(data(TDEIO::Job *, const TQByteArray &)),
+ this, TQT_SLOT(slotData(TDEIO::Job *, const TQByteArray &)));
+ TQObject::connect(m_job, TQT_SIGNAL(result(TDEIO::Job *)),
+ this, TQT_SLOT(slotResult(TDEIO::Job *)));
+ TQObject::connect(m_job, TQT_SIGNAL(mimetype(TDEIO::Job *, const TQString &)),
+ this, TQT_SLOT(slotScanMimeType(TDEIO::Job *, const TQString &)));
+ TQObject::connect(m_job, TQT_SIGNAL(totalSize( TDEIO::Job *, TDEIO::filesize_t)),
+ this, TQT_SLOT(slotTotalSize(TDEIO::Job *, TDEIO::filesize_t)));
m_streamStarted = true;
}
-void KIOInputStream_impl::streamEnd()
+void TDEIOInputStream_impl::streamEnd()
{
kdDebug( 400 ) << "streamEnd()\n";
if(m_job != 0)
{
- TQObject::disconnect(m_job, TQT_SIGNAL(data(KIO::Job *, const TQByteArray &)),
- this, TQT_SLOT(slotData(KIO::Job *, const TQByteArray &)));
- TQObject::disconnect(m_job, TQT_SIGNAL(result(KIO::Job *)),
- this, TQT_SLOT(slotResult(KIO::Job *)));
- TQObject::disconnect(m_job, TQT_SIGNAL(mimetype(KIO::Job *, const TQString &)),
- this, TQT_SLOT(slotScanMimeType(KIO::Job *, const TQString &)));
- TQObject::disconnect(m_job, TQT_SIGNAL(totalSize( KIO::Job *, KIO::filesize_t)),
- this, TQT_SLOT(slotTotalSize(KIO::Job *, KIO::filesize_t)));
+ TQObject::disconnect(m_job, TQT_SIGNAL(data(TDEIO::Job *, const TQByteArray &)),
+ this, TQT_SLOT(slotData(TDEIO::Job *, const TQByteArray &)));
+ TQObject::disconnect(m_job, TQT_SIGNAL(result(TDEIO::Job *)),
+ this, TQT_SLOT(slotResult(TDEIO::Job *)));
+ TQObject::disconnect(m_job, TQT_SIGNAL(mimetype(TDEIO::Job *, const TQString &)),
+ this, TQT_SLOT(slotScanMimeType(TDEIO::Job *, const TQString &)));
+ TQObject::disconnect(m_job, TQT_SIGNAL(totalSize( TDEIO::Job *, TDEIO::filesize_t)),
+ this, TQT_SLOT(slotTotalSize(TDEIO::Job *, TDEIO::filesize_t)));
if ( m_streamPulled )
outdata.endPull();
@@ -117,14 +117,14 @@ void KIOInputStream_impl::streamEnd()
m_streamStarted = false;
}
-bool KIOInputStream_impl::openURL(const std::string& url)
+bool TDEIOInputStream_impl::openURL(const std::string& url)
{
m_url = KURL(url.c_str());
m_size = 0;
return true;
}
-void KIOInputStream_impl::slotData(KIO::Job *, const TQByteArray &data)
+void TDEIOInputStream_impl::slotData(TDEIO::Job *, const TQByteArray &data)
{
if(m_finished)
m_finished = false;
@@ -136,7 +136,7 @@ void KIOInputStream_impl::slotData(KIO::Job *, const TQByteArray &data)
processQueue();
}
-void KIOInputStream_impl::slotResult(KIO::Job *job)
+void TDEIOInputStream_impl::slotResult(TDEIO::Job *job)
{
// jobs delete themselves after emitting their result
m_finished = true;
@@ -151,38 +151,38 @@ void KIOInputStream_impl::slotResult(KIO::Job *job)
}
}
-void KIOInputStream_impl::slotScanMimeType(KIO::Job *, const TQString &mimetype)
+void TDEIOInputStream_impl::slotScanMimeType(TDEIO::Job *, const TQString &mimetype)
{
kdDebug( 400 ) << "got mimetype: " << mimetype << endl;
emit mimeTypeFound(mimetype);
}
-void KIOInputStream_impl::slotTotalSize(KIO::Job *, KIO::filesize_t size)
+void TDEIOInputStream_impl::slotTotalSize(TDEIO::Job *, TDEIO::filesize_t size)
{
m_size = size;
}
-bool KIOInputStream_impl::eof()
+bool TDEIOInputStream_impl::eof()
{
return (m_finished && m_data.size() == 0);
}
-bool KIOInputStream_impl::seekOk()
+bool TDEIOInputStream_impl::seekOk()
{
return false;
}
-long KIOInputStream_impl::size()
+long TDEIOInputStream_impl::size()
{
return m_size ? m_size : m_data.size();
}
-long KIOInputStream_impl::seek(long)
+long TDEIOInputStream_impl::seek(long)
{
return -1;
}
-void KIOInputStream_impl::processQueue()
+void TDEIOInputStream_impl::processQueue()
{
if(m_job != 0)
{
@@ -210,7 +210,7 @@ void KIOInputStream_impl::processQueue()
}
}
-void KIOInputStream_impl::request_outdata(DataPacket<mcopbyte> *packet)
+void TDEIOInputStream_impl::request_outdata(DataPacket<mcopbyte> *packet)
{
processQueue();
packet->size = std::min(m_packetSize, (unsigned int)m_data.size());
@@ -233,4 +233,4 @@ void KIOInputStream_impl::request_outdata(DataPacket<mcopbyte> *packet)
packet->send();
}
-REGISTER_IMPLEMENTATION(KIOInputStream_impl);
+REGISTER_IMPLEMENTATION(TDEIOInputStream_impl);
diff --git a/arts/kde/kioinputstream_impl.h b/arts/kde/kioinputstream_impl.h
index 5377fc808..1d18f6421 100644
--- a/arts/kde/kioinputstream_impl.h
+++ b/arts/kde/kioinputstream_impl.h
@@ -24,21 +24,21 @@
#include <tqobject.h>
#include <tqcstring.h>
-#include <kio/jobclasses.h>
+#include <tdeio/jobclasses.h>
#include <kurl.h>
#include "artskde.h"
#include "stdsynthmodule.h"
namespace Arts {
-class KIOInputStream_impl : public TQObject, virtual public KIOInputStream_skel,
+class TDEIOInputStream_impl : public TQObject, virtual public TDEIOInputStream_skel,
virtual public InputStream_skel,
virtual public StdSynthModule
{
Q_OBJECT
public:
- KIOInputStream_impl();
- ~KIOInputStream_impl();
+ TDEIOInputStream_impl();
+ ~TDEIOInputStream_impl();
void streamStart();
void streamEnd();
@@ -62,14 +62,14 @@ signals:
void mimeTypeFound(const TQString & mimetype);
private slots:
- void slotData(KIO::Job *, const TQByteArray &);
- void slotResult(KIO::Job *);
- void slotScanMimeType(KIO::Job *, const TQString &mimetype);
- void slotTotalSize(KIO::Job *, KIO::filesize_t size);
+ void slotData(TDEIO::Job *, const TQByteArray &);
+ void slotResult(TDEIO::Job *);
+ void slotScanMimeType(TDEIO::Job *, const TQString &mimetype);
+ void slotTotalSize(TDEIO::Job *, TDEIO::filesize_t size);
private:
KURL m_url;
- KIO::TransferJob *m_job;
+ TDEIO::TransferJob *m_job;
TQByteArray m_data;
bool m_finished;
bool m_firstBuffer;
@@ -79,7 +79,7 @@ private:
unsigned int m_packetBuffer;
const unsigned int m_packetSize;
- KIO::filesize_t m_size;
+ TDEIO::filesize_t m_size;
static const unsigned int PACKET_COUNT;
};
diff --git a/arts/kde/kiotest.cc b/arts/kde/kiotest.cc
index b5403ce0d..ed9a3fadf 100644
--- a/arts/kde/kiotest.cc
+++ b/arts/kde/kiotest.cc
@@ -1,10 +1,10 @@
#include <stdio.h>
#include <kmedia2.h>
-#include <kcmdlineargs.h>
+#include <tdecmdlineargs.h>
#include <connect.h>
-#include <klocale.h>
-#include <kapplication.h>
-#include <kaboutdata.h>
+#include <tdelocale.h>
+#include <tdeapplication.h>
+#include <tdeaboutdata.h>
#include "qiomanager.h"
#include "artskde.h"
@@ -12,25 +12,25 @@ using namespace std;
using namespace Arts;
-static KCmdLineOptions options[] =
+static TDECmdLineOptions options[] =
{
{ "+[URL]", I18N_NOOP("URL to open"), 0 },
- KCmdLineLastOption
+ TDECmdLineLastOption
};
int main(int argc, char **argv)
{
- KAboutData aboutData( "kiotest", I18N_NOOP("KIOTest"), I18N_NOOP("0.1"), "", KAboutData::License_GPL, "");
+ TDEAboutData aboutData( "kiotest", I18N_NOOP("KIOTest"), I18N_NOOP("0.1"), "", TDEAboutData::License_GPL, "");
- KCmdLineArgs::init(argc,argv,&aboutData);
- KCmdLineArgs::addCmdLineOptions(options);
- KApplication app;
+ TDECmdLineArgs::init(argc,argv,&aboutData);
+ TDECmdLineArgs::addCmdLineOptions(options);
+ TDEApplication app;
QIOManager qiomanager;
Dispatcher dispatcher(&qiomanager);
- KIOInputStream stream;
+ TDEIOInputStream stream;
StdoutWriter writer;
- KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
+ TDECmdLineArgs *args = TDECmdLineArgs::parsedArgs();
if(args->count())
{
diff --git a/arts/kde/kiotestslow.cc b/arts/kde/kiotestslow.cc
index fd5f1e129..93bfac388 100644
--- a/arts/kde/kiotestslow.cc
+++ b/arts/kde/kiotestslow.cc
@@ -1,10 +1,10 @@
#include <stdio.h>
#include <kmedia2.h>
-#include <kcmdlineargs.h>
+#include <tdecmdlineargs.h>
#include <connect.h>
-#include <klocale.h>
-#include <kapplication.h>
-#include <kaboutdata.h>
+#include <tdelocale.h>
+#include <tdeapplication.h>
+#include <tdeaboutdata.h>
#include <stdsynthmodule.h>
#include "qiomanager.h"
#include "artskde.h"
@@ -78,31 +78,31 @@ public:
REGISTER_IMPLEMENTATION(KIOTestSlow_impl);
};
-static KCmdLineOptions options[] =
+static TDECmdLineOptions options[] =
{
{ "+[URL]", I18N_NOOP("URL to open"), 0 },
- KCmdLineLastOption
+ TDECmdLineLastOption
};
#undef USE_FILEINPUTSTREAM
int main(int argc, char **argv)
{
- KAboutData aboutData( "kiotestslow", I18N_NOOP("KIOTest"), I18N_NOOP("0.1"), "", KAboutData::License_GPL, "");
+ TDEAboutData aboutData( "kiotestslow", I18N_NOOP("KIOTest"), I18N_NOOP("0.1"), "", TDEAboutData::License_GPL, "");
- KCmdLineArgs::init(argc,argv,&aboutData);
- KCmdLineArgs::addCmdLineOptions(options);
- KApplication app;
+ TDECmdLineArgs::init(argc,argv,&aboutData);
+ TDECmdLineArgs::addCmdLineOptions(options);
+ TDEApplication app;
QIOManager qiomanager;
Dispatcher dispatcher(&qiomanager);
#ifndef USE_FILEINPUTSTREAM
- KIOInputStream stream;
+ TDEIOInputStream stream;
#else
FileInputStream stream;
#endif
KIOTestSlow writer;
- KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
+ TDECmdLineArgs *args = TDECmdLineArgs::parsedArgs();
if(args->count())
{
diff --git a/arts/kde/kplayobject.h b/arts/kde/kplayobject.h
index 4aafe0b58..f5bd849be 100644
--- a/arts/kde/kplayobject.h
+++ b/arts/kde/kplayobject.h
@@ -126,7 +126,7 @@ class PlayObjectFactory;
* This class acts as a general interface to the KDE multimedia framework.
* You basically point the Playobject to an URL and say "play", and it will
* automatically decode and play and / or display the file or stream.
- * For non-local media, it will make extensive use of KIOInputStream to
+ * For non-local media, it will make extensive use of TDEIOInputStream to
* directly play the content from the remote location without having to
* download it to a temporary local file first.
*
diff --git a/arts/kde/kplayobjectcreator.cc b/arts/kde/kplayobjectcreator.cc
index b1969718e..039c8a3bc 100644
--- a/arts/kde/kplayobjectcreator.cc
+++ b/arts/kde/kplayobjectcreator.cc
@@ -19,7 +19,7 @@
*/
-#include <kio/kmimetype.h>
+#include <tdeio/kmimetype.h>
#include "artskde.h"
#include "kplayobjectcreator.h"
#include "kplayobjectcreator.moc"
@@ -53,8 +53,8 @@ bool KDE::PlayObjectCreator::create(const KURL& url, bool createBUS, const TQObj
m_createBUS = createBUS;
// This is the RightWay(tm) according to stw
- Arts::KIOInputStream_impl* instream_impl = new Arts::KIOInputStream_impl();
- m_instream = Arts::KIOInputStream::_from_base(instream_impl);
+ Arts::TDEIOInputStream_impl* instream_impl = new Arts::TDEIOInputStream_impl();
+ m_instream = Arts::TDEIOInputStream::_from_base(instream_impl);
// signal will be called once the ioslave knows the mime-type of the stream
connect(instream_impl, TQT_SIGNAL(mimeTypeFound(const TQString &)),
diff --git a/arts/kde/kplayobjectcreator.h b/arts/kde/kplayobjectcreator.h
index d52e18a1e..74e571c8e 100644
--- a/arts/kde/kplayobjectcreator.h
+++ b/arts/kde/kplayobjectcreator.h
@@ -46,7 +46,7 @@ private slots:
private:
Arts::SoundServerV2 m_server;
- Arts::KIOInputStream m_instream;
+ Arts::TDEIOInputStream m_instream;
Arts::PlayObject playObject;
bool m_createBUS;
};
diff --git a/arts/kde/kvideowidget.cpp b/arts/kde/kvideowidget.cpp
index bc17f32d8..c03a18c21 100644
--- a/arts/kde/kvideowidget.cpp
+++ b/arts/kde/kvideowidget.cpp
@@ -26,8 +26,8 @@
#define XEvent void
#endif
-#include <kaction.h>
-#include <klocale.h>
+#include <tdeaction.h>
+#include <tdelocale.h>
#include "kvideowidget.h"
@@ -101,22 +101,22 @@ void KVideoWidget::init(void)
videoHeight = 0;
// Setup actions
- new KToggleAction( i18n("Fullscreen &Mode"), "window_fullscreen",
+ new TDEToggleAction( i18n("Fullscreen &Mode"), "window_fullscreen",
CTRL+SHIFT+Key_F, TQT_TQOBJECT(this), TQT_SLOT(fullscreenActivated()),
actionCollection(), "fullscreen_mode" );
- new KRadioAction( i18n("&Half Size"), ALT+Key_0,
+ new TDERadioAction( i18n("&Half Size"), ALT+Key_0,
TQT_TQOBJECT(this), TQT_SLOT(halfSizeActivated()),
actionCollection(), "half_size" );
- new KRadioAction( i18n("&Normal Size"), ALT+Key_1,
+ new TDERadioAction( i18n("&Normal Size"), ALT+Key_1,
TQT_TQOBJECT(this), TQT_SLOT(normalSizeActivated()),
actionCollection(), "normal_size" );
- new KRadioAction( i18n("&Double Size"), ALT+Key_2,
+ new TDERadioAction( i18n("&Double Size"), ALT+Key_2,
TQT_TQOBJECT(this), TQT_SLOT(doubleSizeActivated()),
actionCollection(), "double_size" );
- ((KToggleAction *)action( "half_size" ))->setExclusiveGroup( "KVideoWidget::zoom" );
- ((KToggleAction *)action( "normal_size" ))->setExclusiveGroup( "KVideoWidget::zoom" );
- ((KToggleAction *)action( "double_size" ))->setExclusiveGroup( "KVideoWidget::zoom" );
+ ((TDEToggleAction *)action( "half_size" ))->setExclusiveGroup( "KVideoWidget::zoom" );
+ ((TDEToggleAction *)action( "normal_size" ))->setExclusiveGroup( "KVideoWidget::zoom" );
+ ((TDEToggleAction *)action( "double_size" ))->setExclusiveGroup( "KVideoWidget::zoom" );
action("double_size")->setEnabled(false);
action("half_size")->setEnabled(false);
@@ -232,29 +232,29 @@ bool KVideoWidget::isEmbedded()
bool KVideoWidget::isFullscreen()
{
- return ((KToggleAction *)action( "fullscreen_mode" ))->isChecked();
+ return ((TDEToggleAction *)action( "fullscreen_mode" ))->isChecked();
}
bool KVideoWidget::isHalfSize()
{
- return ((KToggleAction *)action( "half_size" ))->isChecked();
+ return ((TDEToggleAction *)action( "half_size" ))->isChecked();
}
bool KVideoWidget::isNormalSize()
{
- return ((KToggleAction *)action( "normal_size" ))->isChecked();
+ return ((TDEToggleAction *)action( "normal_size" ))->isChecked();
}
bool KVideoWidget::isDoubleSize()
{
- return ((KToggleAction *)action( "double_size" ))->isChecked();
+ return ((TDEToggleAction *)action( "double_size" ))->isChecked();
}
void KVideoWidget::setFullscreen()
{
if (!isFullscreen())
{
- ((KToggleAction *)action( "fullscreen_mode" ))->setChecked( true );
+ ((TDEToggleAction *)action( "fullscreen_mode" ))->setChecked( true );
fullscreenActivated();
}
}
@@ -263,26 +263,26 @@ void KVideoWidget::setWindowed()
{
if (isFullscreen())
{
- ((KToggleAction *)action( "fullscreen_mode" ))->setChecked( false );
+ ((TDEToggleAction *)action( "fullscreen_mode" ))->setChecked( false );
fullscreenActivated();
}
}
void KVideoWidget::setHalfSize()
{
- ((KToggleAction *)action( "half_size" ))->setChecked( true );
+ ((TDEToggleAction *)action( "half_size" ))->setChecked( true );
halfSizeActivated();
}
void KVideoWidget::setNormalSize()
{
- ((KToggleAction *)action( "normal_size" ))->setChecked( true );
+ ((TDEToggleAction *)action( "normal_size" ))->setChecked( true );
normalSizeActivated();
}
void KVideoWidget::setDoubleSize()
{
- ((KToggleAction *)action( "double_size" ))->setChecked( true );
+ ((TDEToggleAction *)action( "double_size" ))->setChecked( true );
doubleSizeActivated();
}
@@ -323,18 +323,18 @@ void KVideoWidget::resizeEvent( TQResizeEvent *event )
{
if (width() == QMAX( (videoWidth / 2), minimumWidth() ) &&
height() == QMAX( (videoHeight / 2), minimumHeight() ))
- ((KToggleAction *)action( "half_size" ))->setChecked( true );
+ ((TDEToggleAction *)action( "half_size" ))->setChecked( true );
else if (width() == QMAX( videoWidth, minimumWidth() ) &&
height() == QMAX( videoHeight, minimumHeight() ))
- ((KToggleAction *)action( "normal_size" ))->setChecked( true );
+ ((TDEToggleAction *)action( "normal_size" ))->setChecked( true );
else if (width() == QMAX( (2 * videoWidth), minimumWidth() ) &&
height() == QMAX( (2 * videoHeight), minimumHeight() ))
- ((KToggleAction *)action( "double_size" ))->setChecked( true );
+ ((TDEToggleAction *)action( "double_size" ))->setChecked( true );
else
{
- ((KToggleAction *)action( "half_size" ))->setChecked( false );
- ((KToggleAction *)action( "normal_size" ))->setChecked( false );
- ((KToggleAction *)action( "double_size" ))->setChecked( false );
+ ((TDEToggleAction *)action( "half_size" ))->setChecked( false );
+ ((TDEToggleAction *)action( "normal_size" ))->setChecked( false );
+ ((TDEToggleAction *)action( "double_size" ))->setChecked( false );
}
}
}
diff --git a/arts/kde/mcop-dcop/kmcop.cpp b/arts/kde/mcop-dcop/kmcop.cpp
index 2ba71b64c..d5e8c8642 100644
--- a/arts/kde/mcop-dcop/kmcop.cpp
+++ b/arts/kde/mcop-dcop/kmcop.cpp
@@ -18,9 +18,9 @@
#include <kdebug.h>
#include <kuniqueapplication.h>
-#include <kaboutdata.h>
-#include <kcmdlineargs.h>
-#include <klocale.h>
+#include <tdeaboutdata.h>
+#include <tdecmdlineargs.h>
+#include <tdelocale.h>
#include <dcopclient.h>
#include <tqvaluelist.h>
@@ -48,12 +48,12 @@ public:
int main(int argc, char **argv)
{
- KAboutData aboutdata("kmcop", I18N_NOOP("KMCOP"),
+ TDEAboutData aboutdata("kmcop", I18N_NOOP("KMCOP"),
"0.1", I18N_NOOP("TDE MCOP-DCOP Bridge"),
- KAboutData::License_GPL, "(C) 2001, Nikolas Zimmermann");
+ TDEAboutData::License_GPL, "(C) 2001, Nikolas Zimmermann");
aboutdata.addAuthor("Nikolas Zimmermann", I18N_NOOP("Author"), "wildfox@kde.org");
- KCmdLineArgs::init(argc, argv, &aboutdata);
+ TDECmdLineArgs::init(argc, argv, &aboutdata);
KUniqueApplication::addCmdLineOptions();
if(!KUniqueApplication::start())
diff --git a/arts/kde/kplayobjectfactory.cc b/arts/kde/kplayobjectfactory.cc
index 29ee20e3d..1b6be9860 100644
--- a/arts/kde/kplayobjectfactory.cc
+++ b/arts/kde/kplayobjectfactory.cc
@@ -19,7 +19,7 @@
*/
-#include <kio/kmimetype.h>
+#include <tdeio/kmimetype.h>
#include "kplayobject.h"
#include "artskde.h"
#include "kplayobjectfactory.h"
@@ -33,7 +33,7 @@
#include <kdebug.h>
#include "kaudiomanagerplay.h"
#include <flowsystem.h>
-#include <kio/netaccess.h>
+#include <tdeio/netaccess.h>
using namespace std;
@@ -68,14 +68,14 @@ KPlayObject *KPlayObjectFactory::createPlayObject(const KURL& _url, const TQStri
// I hate it
// I hate it
// It sucks
- // kio_media please die
- KURL url = KIO::NetAccess::mostLocalURL(_url, 0);
+ // tdeio_media please die
+ KURL url = TDEIO::NetAccess::mostLocalURL(_url, 0);
if(!m_server.isNull())
{
if(mimetype == "application/octet-stream" && m_allowStreaming)
{
- Arts::KIOInputStream instream;
+ Arts::TDEIOInputStream instream;
instream.openURL(url.url().latin1());
m_stream = true;
@@ -139,8 +139,8 @@ KDE::PlayObject *KDE::PlayObjectFactory::createPlayObject(const KURL& _url, cons
// I hate it
// I hate it
// It sucks
- // kio_media please die
- KURL url = KIO::NetAccess::mostLocalURL(_url, 0);
+ // tdeio_media please die
+ KURL url = TDEIO::NetAccess::mostLocalURL(_url, 0);
// return a NULL playobject if the server is NULL
if ( d->server.isNull() || url.isEmpty() )
@@ -154,7 +154,7 @@ KDE::PlayObject *KDE::PlayObjectFactory::createPlayObject(const KURL& _url, cons
createBUS = false;
}
// decide if it's a local file. mpeglib provides cdda reading and decoding, so we prefer that over kio_audiocd
if ( url.isLocalFile() || !d->allowStreaming || (url.protocol() == "audiocd" && mimetype == "application/x-cda" && mimeTypes().contains( "application/x-cda" ) ) )
{
// we rely on the delivered mimetype if it's a local file
@@ -154,7 +154,7 @@ KDE::PlayObject *KDE::PlayObjectFactory::createPlayObject(const KURL& _url, cons
createBUS = false;
}
- // decide if it's a local file. mpeglib provides cdda reading and decoding, so we prefer that over kio_audiocd
+ // decide if it's a local file. mpeglib provides cdda reading and decoding, so we prefer that over tdeio_audiocd
if ( url.isLocalFile() || !d->allowStreaming || (url.protocol() == "audiocd" && mimetype == "application/x-cda" && mimeTypes().contains( "application/x-cda" ) ) )
{